import QtQuick 1.1

Item {
    id: me
    width: size;
    height: text!="" ? size/ratio : size;

    property int buttonId: 0;
    property color baseColor: "white";
    property color toColor: Qt.lighter(baseColor, colorRatio);
    property alias text: btnText.text;
    property alias textColor: btnText.color;
    property alias source: btnImage.source;
    property int speed: 240;
    property int size: autoSize ? parent.width : 230;
    property bool autoSize: true
    property real ratio: 1.0;
    property real colorRatio: 2.0;
    property real radiusRatio: 6.0;
    property alias enabled: ma.enabled
    property real pressedScale: 1.1

    signal clicked(int id)

    MouseArea {
        id: ma
        anchors.fill: parent
        onClicked: {
            me.clicked(buttonId);
        }
    }

    Rectangle {
        id: bgr
        radius: size/radiusRatio;
        color: "black"
        scale: (ma.enabled && ma.pressed) ? pressedScale : 1.0;
        smooth: true
        anchors.fill: parent;
        visible: text!=""

        Behavior on scale { NumberAnimation { easing.type: Easing.InOutCubic; duration: 80 } }

        Text {
            id: btnText
            anchors.margins: bgr.radius;
            anchors.centerIn: parent;
            font.pixelSize: me.height-32;
            text: text;
            visible: text!=""
            color: "black";
        }
    }

    Image {
        id: btnImage
        anchors.centerIn: parent;
        scale: (ma.enabled && ma.pressed) ? pressedScale : 1.0;
        Behavior on scale { NumberAnimation { easing.type: Easing.InOutCubic; duration: 80 } }
        width: size;
        height: size;
        visible: text===""
        smooth: true;
        opacity: ma.enabled ? 1.0 : 0.5;
        sourceSize {
            width: me.size
            height: me.size;
        }
    }
}

