import QtQuick 1.1
import Box2D 1.0

Item {
    id: bike
    parent: world;

    property int centerX: (rWheel.x+fWheel.x)/2
    property int centerY: (rWheel.y+fWheel.y+bodyCenter.y)/3
    property bool canJump: false;
    property int jumpForce: 2200;
    property alias speed: motor.motorSpeed
    property real wheelSize: 48.5
    property bool inAir: !rWheel.isOnGround || !fWheel.isOnGround;

    onSpeedChanged: console.debug("Speed:"+speed);

    signal bikeBroke;

    width: fWheel.size * 2.7;
    height: fWheel.size * 1.8;

    function pedal() {
        motor.enableMotor=true;
        motor.maxMotorTorque=30;
        motor.motorSpeed=30;
    }

    function kickPedal() {
        rWheel.applyTorque(-150);
    }

    function reverse() {
        rWheel.applyTorque(50);
    }

    function stopPedal() {
        motor.enableMotor=true;
        motor.maxMotorTorque=2.5;
        motor.motorSpeed=0;
    }

    function brakeBack() {
        motor.enableMotor=true;
        motor.maxMotorTorque=40;
        motor.motorSpeed=0;
    }

    function freeBrakeBack() {
        motor.maxMotorTorque=5;
    }

    function brakeFront() {
        frontWheelToFrontFork.maxMotorTorque=5000;
    }

    function freeBrakeFront() {
        frontWheelToFrontFork.maxMotorTorque=4;
    }

    function jumpWheel() {
        if (!player.alive)
            return;

        if (rWheel.isOnGround)
            rWheel.applyLinearImpulse(Qt.point(0, -bike.jumpForce), rWheel.getWorldPoint(Qt.point(0.5,0)))

        if (fWheel.isOnGround)
            fWheel.applyLinearImpulse(Qt.point(0, -bike.jumpForce), fWheel.getWorldPoint(Qt.point(0.5,0)))
    }

    function jump() {
        if (!player.alive)
            return;

        if (rWheel.isOnGround || fWheel.isOnGround)
            bodyCenter.applyLinearImpulse(Qt.point(0, -bike.jumpForce), bodyCenter.getWorldPoint(Qt.point(0.5,0.5)))
    }

    function reset() {
        world.resetVelocities();
        bike.y=100;
        bodyCenter.rotation=-1;
        frontFork.rotation=-104;
        rearFork.rotation=-49;
        bodyFork.rotation=-38;
        player.rotation=0;
        bodyMiddleFork.rotation=-100;        
    }

    function die() {
        player.alive=false;
    }

    function killBikeFront() {
        frontWheelToFrontFork.release();
        bikeBroke();
    }

    function killBikeBack() {
        motor.release();
        bikeBroke();
    }

    Wheel {
        id: fWheel
        parent: world
        x: bike.x + bike.width - fWheel.size/2;
        y: bike.y + bike.height/2;
        size: wheelSize

        onBeginContact: {
            if (y>1000)
                killBikeFront();
        }
    }

    Body {
        id: frontFork
        parent: bike.parent
        fixedRotation: false
        sleepingAllowed: true
        x: bike.x + bike.width - fWheel.size/2;
        y: bike.y + bike.height/2;
        width: fWheel.width;
        height: rWheel.width/11;
        rotation: -104

        fixtures: Box {
            friction: 1.0;
            density: 1.0;
            anchors.fill: parent

        }
        Rectangle {
            anchors.fill: parent
            color: "green"
        }
    }

    Wheel {
        id: rWheel
        parent: world
        x: bike.x + rWheel.size/2;
        y: bike.y + bike.height/2;
        size: wheelSize
        onBeginContact: {
            if (y>1000)
                killBikeBack();
        }
    }

    Body {
        id: rearFork
        parent: bike.parent
        fixedRotation: false
        sleepingAllowed: true
        x: bike.x + rWheel.size/2;
        y: bike.y + bike.height/2;
        width: rWheel.size;
        height: rWheel.width/11;
        rotation: -49

        fixtures: Box {
            friction: 1.0;
            density: 1.0;
            anchors.fill: parent

        }
        Rectangle {
            anchors.fill: parent
            color: "red"
        }
    }

    Body {
        id: bodyCenter
        parent: bike.parent
        fixedRotation: false
        sleepingAllowed: true
        x: bike.x+bike.width/2.8;
        y: bike.y+bike.height/9;
        width: rWheel.width*1.2;
        height: rWheel.width/11;
        rotation: -1
        angularDamping: 20.0
        bodyType: Body.Dynamic

        fixtures: Box {
            friction: 1.0;
            density: 10.0;
            anchors.fill: parent

        }
        Rectangle {
            anchors.fill: parent
            color: "blue"
        }
    }

    Body {
        id: bodyFork
        parent: bike.parent
        fixedRotation: false
        sleepingAllowed: true
        x: bike.x + rWheel.size*1.1;
        y: bike.y + bike.height/1.9;
        width: rWheel.size*1.3;
        height: rWheel.width/11;
        rotation: -38
        angularDamping: 20.0

        fixtures: Box {
            friction: 1.0;
            density: 1.0;
            anchors.fill: parent

        }
        Rectangle {
            anchors.fill: parent
            color: "yellow"
        }
    }

    Body {
        id: bodyMiddleFork
        parent: bike.parent
        fixedRotation: false
        sleepingAllowed: true
        x: bike.x + rWheel.size*1.1;
        y: bike.y + bike.height/1.9;
        width: rWheel.size*1.2;
        height: rWheel.width/11;
        rotation: -100
        angularDamping: 20.0

        fixtures: Box {
            friction: 1.0;
            density: 1.0;
            anchors.fill: parent

        }
        Rectangle {
            anchors.fill: parent
            color: "orange"
        }
    }

    WeldJoint {
        id: rForkToBody
        parent: bike.parent
        bodyA: rearFork
        bodyB: bodyCenter
    }

    WeldJoint {
        id: fForkToBody
        parent: bike.parent
        bodyA: frontFork
        bodyB: bodyCenter
    }

    WeldJoint {
        id: fForkToBodyF
        parent: bike.parent
        bodyA: frontFork
        bodyB: bodyFork
    }

    WeldJoint {
        id: bfForkToBody
        parent: bike.parent
        bodyA: bodyFork
        bodyB: bodyCenter
    }

    WeldJoint {
        id: bmForkToBody
        parent: bike.parent
        bodyA: bodyMiddleFork
        bodyB: bodyCenter
    }

    WeldJoint {
        id: fForkToMBodyF
        parent: bike.parent
        bodyA: bodyMiddleFork
        bodyB: bodyFork
    }

    RevoluteJoint {
        id: motor
        parent: bike.parent
        maxMotorTorque: 2.5
        motorSpeed: 0
        enableMotor: true;
        bodyA: rWheel
        bodyB: rearFork
    }

    RevoluteJoint {
        id: frontWheelToFrontFork
        parent: bike.parent
        maxMotorTorque: 2
        motorSpeed: 0
        enableMotor: true;
        bodyA: fWheel
        bodyB: frontFork
    }

    Cyclist {
        x: bike.x + rWheel.size*0.8;
        y: bike.y - rWheel.size*1.3;
        width: rWheel.size*0.8;
        height: rWheel.size*1.0
        parent: bike.parent
        id: player

        onBeginContact: {
            console.debug("X:"+x)
            console.debug("Y:"+y)
            console.debug("R:"+rotation)
            // release if any of the forces are too much
            if (x*y>2500)
                cyclistToBike.release();
                player.alive=false;
        }
    }

    RevoluteJoint {
        id: cyclistToBike
        parent: bike.parent
        maxMotorTorque: 6
        motorSpeed: 0
        enableMotor: true;
        enableLimit: true;
        lowerAngle: -1;
        upperAngle: 1;
        bodyA: player
        bodyB: bodyMiddleFork
    }
}
