import QtQuick 1.1
import Box2D 1.0

Item {
    id: p

    property int centerX: pb.x
    property int centerY: pb.y

    property bool debug: false;

    property int group: 0
    signal beginContact(variant other, real x, real y);
    signal endContact(variant other);
    signal hitHead(variant other,  real x, real y);

    property int gravityScale: 1;
    property variant player: null;

    property int gid: 2000;       
    property bool isRigid: true;

    parent: world;

    function getBody()
    {
        return pb
    }

    function makeRagdoll()
    {
        isRigid=false;
    }

    function headStarBurst(starLevel)
    {
        head.fireworks(starLevel);
    }

    function getFeet1() { return feet1 }
    function getHand1() { return hand1 }

    function getFeet2() { return feet2 }
    function getHand2() { return hand2 }

    function getPlayer(h) {        
        return player;
    }

    Component.onCompleted: {
        console.debug("Otter is ready");
        console.debug("Player:"+player)
    }

    Body  {
        id: pb

        fixedRotation: false
        sleepingAllowed: true
        angularDamping: isRigid ? 50.0 : 10.0;
        parent: p.parent;
        gravityScale: p.gravityScale

        property int gid: 2000;               

        function getPlayer() { return p.getPlayer(); }

        x: p.x;
        y: p.y;
        width: p.width;
        height: p.height;
        rotation: 0
        z: 2

        fixtures: [
            Polygon {
                id: body1;
                friction: 1;
                density: 0.2;
                groupIndex: p.group
                onBeginContact: p.beginContact(p, pb.linearVelocity.x, pb.linearVelocity.y);
                onEndContact: p.endContact(p);

                vertices: [
                    Qt.point(p.width/2, 0),
                    Qt.point(p.width/2.2, p.height/2),
                    Qt.point(p.width, p.height/1.9),
                    Qt.point(p.width, 0)
                ]

            },
            Polygon {
                friction: 1;
                density: 0.6;
                groupIndex: p.group
                onBeginContact: p.beginContact(p, pb.linearVelocity.x, pb.linearVelocity.y);
                onEndContact: p.endContact(p);

                vertices: [
                    Qt.point(p.width/2.2, p.height/2),
                    Qt.point(0, p.height/1.08),
                    Qt.point(p.width/2.25, p.height),
                    Qt.point(p.width, p.height/1.9),
                ]
            }
        ]

        Image {
            id: bs
            width: p.width;
            height: p.height;
            source: "images/otty/body.svg"
            visible: !debug;
            smooth: _isFast;
            sourceSize {
                width: 273/3
                height: 601/3
            }
        }

    }

    Head {
        id: head
        x: p.x+p.width/1.2
        y: p.y-head.height/9;
        size: 30;
        density: 0.1;
        group: p.group
        parent: p.parent;
        z: 3;
        visible: !debug;
        gid: p.gid;

        onBeginContact: p.hitHead(other, lvx, lvy);

        function getPlayer() { return p.getPlayer(); }
    }

    property real feetBodyX: p.x+p.width/8;
    property real feetBodyY: p.y+p.height-feet1.height/1.6;

    Feet {
        id: feet1
        x: feetBodyX
        y: feetBodyY;
        group: p.group
        parent: p.parent;
        visible: !debug;
        z: 1;
    }

    Feet {
        id: feet2
        x: feetBodyX
        y: feetBodyY;
        group: p.group
        parent: p.parent;
        visible: !debug;
        z: 3
    }

    property real tailBodyX: p.x-tail.width/1.3;
    property real tailBodyY: p.y+p.height-tail.height/1.6;

    Tail {
        id: tail
        x: tailBodyX
        y: tailBodyY;
        group: p.group
        parent: p.parent;
        z: 3
    }

    property real handBodyY: p.y+p.height/2.8;

    Hand {
        id: hand1
        x: p.x+p.width/1.9
        y: handBodyY
        size: 28
        rotation: 6;
        group: p.group
        parent: p.parent;
        rightHand: false;
        z: 1;
        visible: !debug;
    }

    Hand {
        id: hand2
        x: p.x+p.width/1.9
        y: handBodyY
        size: 28
        group: p.group
        parent: p.parent;
        rotation: -16;
        rightHand: true;
        z: 3;
        visible: !debug;
    }

    RevoluteJoint {
        id: headToBody
        parent: p.parent
        bodyA: pb
        bodyB: head
        enableLimit: true
        maxMotorTorque: 20
        motorSpeed: 0.8;
        enableMotor: true;
        lowerAngle: -0.01;
        upperAngle: 0.03;
        localAnchorA: Qt.point(p.width/1.2, head.height/6)
    }

    RevoluteJoint {
        id: tailToBody
        parent: p.parent
        bodyA: pb
        bodyB: tail
        enableLimit: true
        maxMotorTorque: 10
        motorSpeed: 1
        enableMotor: isRigid;
        lowerAngle: -0.61;
        upperAngle: -0.11;
        localAnchorA: Qt.point(pb.width/3, pb.height/1.1)
        localAnchorB: Qt.point(0, 0)
    }

    RevoluteJoint {
        id: handsToBody
        parent: p.parent
        bodyA: pb
        bodyB: hand1
        enableLimit: true
        maxMotorTorque: 6
        motorSpeed: 0
        enableMotor: false;
        lowerAngle: isRigid ? -0.12 : -0.20;
        upperAngle: isRigid ? 0.18 : 0.22;
        localAnchorA: Qt.point(p.width/1.8, p.height/2)
        localAnchorB: Qt.point(0, 0)
    }

    RevoluteJoint {
        id: hand2ToBody
        parent: p.parent
        bodyA: pb
        bodyB: hand2
        enableLimit: true
        maxMotorTorque: 6
        motorSpeed: 0
        enableMotor: false;
        lowerAngle: isRigid ? -0.12 : -0.20;
        upperAngle: isRigid ? 0.07 : 0.12;
        localAnchorA: Qt.point(p.width/1.8, p.height/2)
        localAnchorB: Qt.point(0, 0)
    }

    property real feetX: p.width/3;
    property real feetY: p.height;

    RevoluteJoint {
        id: feetToBody
        parent: p.parent
        bodyA: pb
        bodyB: feet1
        enableLimit: true
        maxMotorTorque: 4
        motorSpeed: 0
        enableMotor: false;
        lowerAngle: -0.1;
        upperAngle: 0.1;
        localAnchorA: Qt.point(feetX, feetY)
        // localAnchorB: Qt.point(0, 0);
    }
    RevoluteJoint {
        id: feet2ToBody
        parent: p.parent
        bodyA: pb
        bodyB: feet2
        enableLimit: true
        maxMotorTorque: 2
        motorSpeed: 0
        enableMotor: false;
        lowerAngle: -0.1;
        upperAngle: 0.1;
        localAnchorA: Qt.point(feetX, feetY)
    }
}
