import QtQuick 1.1
import Box2D 1.0

Item {
    id: gameArea
    anchors.fill: parent
    focus: true
    width: 1000;
    height: 600;

    Keys.onPressed: {
        if (event.isAutoRepeat)
            return;

        if (event.key === Qt.Key_Right)
            pedal();

        if (event.key === Qt.Key_Left)
            brake();

        if (event.key === Qt.Key_Up)
            jump();
            
        if (event.key === Qt.Key_Plus)
            world.zoomIn();

        if (event.key === Qt.Key_Minus)
            world.zoomOut();

        if (event.key === Qt.Key_End)
            world.zoomOutDebug();
    }
    
    Keys.onReleased: {
        if (event.isAutoRepeat)
            return;

        if (event.key === Qt.Key_Left)
            cycle.stopBrake();

        if (event.key === Qt.Key_Right)
            stopPedal();

        if (event.key === Qt.Key_Up)
            stopJump();

        event.accepted = true;
    }

    function pedal()
    {
        cycle.pedal();
        if (cycle.inAir)
            cycle.goForward();
    }

    function stopPedal()
    {
        cycle.stopPedal();
    }

    function jump()
    {
        cycle.jump();
    }

    function brake()
    {
        cycle.brake();
        if (cycle.inAir)
            cycle.goBackward();
    }
    
        Flickable {
        id: f        
        anchors.fill: parent;
        contentHeight: world.height;
        contentWidth: world.width;
        interactive: true;
        contentX: getWorldCenterX(cycle.playerX)
        contentY: getWorldCenterY(cycle.playerY);
        boundsBehavior: Flickable.DragOverBounds


    World {
            id: world;
            width: 1600;
            height: 900;

            property real gameGravity: -9.81;

            gravity {
                x: 0;
                y: gameGravity;
            }

            transform: Scale {
                id: zoom
                origin.x: cycle.playerX-cycle.width/2;
                origin.y: cycle.playerY+cycle.height/1.3;
                xScale: 4.0
                yScale: xScale;
                Behavior on xScale {
                    NumberAnimation { easing.type: Easing.InOutSine; duration: 150 }
                }
            }

            function zoomIn()
            {
                zoom.xScale+=0.5;
            }

            function zoomNormal()
            {
                zoom.xScale=1.25;
            }

            function zoomNormalSpeed()
            {
                zoom.xScale=1.0;
            }

            function zoomClose()
            {
                zoom.xScale=2.5;
            }

            function zoomOut()
            {
                zoom.xScale-=0.5;
            }

            function zoomOutDebug()
            {
                zoom.xScale=0.1;
            }


	KickScooter {
		id: cycle
		x: 100
		y: 300
 	}

         Item {
                id: ground
                height: world.height/8
                anchors {
                    left: parent.left;
                    right: parent.right;
                    bottom: parent.bottom
                }
            }

            Rectangle {
                color: "#713a07"
                x: ground.x
                y: ground.y
                height: 500;
                width: ground.width;
            }

            Ground {
                id: groundBody
                height: world.height/8
                anchors.fill: ground;
            }

            Wall {
                id: leftWall
                width: 10
                anchors { right: parent.left; top: parent.top; bottom: parent.bottom }
            }

            Wall {
                id: rightWall
                width: 10
                anchors { left: parent.right; top: parent.top; bottom: parent.bottom }
            }

            DebugDraw {
                id: debugDraw
                world: world
                anchors.fill: world
                opacity: 1.0
                visible: true
            }
     }
     }
}
