import QtQuick 1.1

Menu {
    id: gameEnd
    margin: 0

    property int displayScore: 0;
    property int droplets: 0;
    property bool btnsEnabled: false;
    property bool btnNextLevelEnabled: false;
    property bool isHighScore: false;

    onStateChanged: {
        if (state==='shown') {
            if (displayScore>0) {
                // levelScore.finalScore=displayScore;
                levelScore.start();
            } else {
                gameEnd.enableButtons();
            }
        }
        if (state==='hidden') {
            gameEndButtons.opacity=0;
            drop1.reset();
            drop2.reset();
            drop3.reset();
            btnsEnabled=false;
        }
    }

    signal nextLevel();
    signal restartLevel();
    signal quitGame(int qtype);

    function setScore(score, drops, ishigh)
    {
        displayScore=score;
        droplets=drops;
        isHighScore=ishigh;
    }

    function setMessage(msg)
    {
        endMsg.text=msg;
    }

    function enableButtons()
    {
        gameEndButtons.opacity=1;
        //btnNextLevel.enabled=true;
        btnQuit.enabled=true;
        btnTryAgain.enabled=true;
    }        

    Column {
        width: parent.width
        anchors.centerIn: parent;
        spacing: 8
        Text {
            id: endMsg;
            text: "";
            font.pixelSize: 36
            anchors.horizontalCenter: parent.horizontalCenter;
        }
        Item {
            anchors.horizontalCenter: parent.horizontalCenter;
            height: 42
            width: parent.width
            Text {
                visible: isHighScore
                scale: 0
                id: hsText
                anchors.centerIn: parent                
                text: qsTr("New High Score!");
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 36
            }
            PropertyAnimation {
                id: hsAnim
                target: hsText
                easing.type: Easing.InQuint
                duration: 1500;
                from: 6
                to: 1
                property: "scale"
            }
        }
        Row {
            anchors.horizontalCenter: parent.horizontalCenter;
            Droplet { id: drop1; onDropletBurst: levelScore.addScore(1000); }
            Droplet { id: drop2; onDropletBurst: levelScore.addScore(1000); }
            Droplet { id: drop3; onDropletBurst: levelScore.addScore(1000); }

            SequentialAnimation {
                id: droplet
                PauseAnimation { duration: 250; }
                ScriptAction { script: if (droplets>0) drop1.gotDroplet(); else drop1.noDroplet(); }
                PauseAnimation { duration: 650; }
                ScriptAction { script: if (droplets>1) drop2.gotDroplet(); else drop2.noDroplet(); }
                PauseAnimation { duration: 650; }
                ScriptAction { script: if (droplets>2) drop3.gotDroplet(); else drop3.noDroplet(); }
                PauseAnimation { duration: 300; }
                ScriptAction { script: if (isHighScore) hsAnim.start(); }
                onCompleted: {
                    gameEnd.enableButtons();
                }
            }

        }
        ScoreDisplay {
            id: levelScore;
            score: 0;
            finalScore: displayScore;
            anchors.horizontalCenter: parent.horizontalCenter;
            isFixed: true;

            onScoreCompleted: {
                droplet.start();
            }
            // onScoreChanged: console.debug("SCORE:"+score)
        }
        Row {
            id: gameEndButtons
            anchors.horizontalCenter: parent.horizontalCenter;
            height: 64;
            width: buttons*64+buttons*32;
            opacity: 0;
            spacing: 32;            

            property int buttons: 2;

            Behavior on opacity { NumberAnimation { duration: 250; } }

            /*
            Button {
                id: btnNextLevel
                source: "images/buttons/next_stage.svg"
                size: 64
                enabled: btnsEnabled && btnNextLevelEnabled
                onClicked: {                    
                    gameEnd.hide();
                    quitGame(1);
                }
            }
            */
            Button {
                id: btnTryAgain
                source: "images/buttons/again.svg"
                size: 64
                enabled: btnsEnabled
                onClicked: {
                    gameEnd.hide();
                    restartLevel();
                }
            }
            Button {
                id: btnQuit
                source: "images/buttons/end.svg"
                size: 64
                enabled: btnsEnabled
                onClicked: {
                    gameEnd.hide();
                    quitGame(0);
                }
            }
        }
    }
}
