import QtQuick 1.1

XmlListModel {
    id: levelModel
    query: "/bsna/level/item"

    XmlRole { name: "n"; query: "@n/string()"; }
    XmlRole { name: "x"; query: "@x/string()"; }
    XmlRole { name: "y"; query: "@y/string()"; }
    XmlRole { name: "s"; query: "@s/string()"; }
    XmlRole { name: "t"; query: "@t/string()"; }
    XmlRole { name: "r"; query: "@r/string()"; }

    property bool loaded: false;
    signal levelLoaded();
    signal levelError(string errorMsg);

    property int playerx: 20;

    onStatusChanged: {
        switch (status) {
        case XmlListModel.Null:
            console.debug("No level data")
            break;
        case XmlListModel.Ready: {
            console.debug("XML Loaded with level items:"+count)
            dumpLevel();
            levelLoaded()
            loaded=true;
        }
        break;
        case XmlListModel.Loading:
            console.debug("XML Loading...")
            break;
        case XmlListModel.Error: {
            console.debug("Level loading error:"+errorString())
            levelError(errorString());
        }
        break;
        }
    }

    function dumpLevel()
    {
        var i;
        console.debug("Level items:"+count)
        console.debug(xml);
        for (i=0;i<count;i++) {
            console.debug("Item:"+levelModel.get(i).n)
            console.debug("PosX:"+levelModel.get(i).x)
            console.debug("PosY:"+levelModel.get(i).y)
        }
    }

    function setLevel(level)
    {
        levelModel.loaded=false;
        levelModel.source='levels/'+level;
        levelModel.reload();
    }

    function getItem(i)
    {
        var gi=new Object;
        var x=get(i).x;
        var y=get(i).y;
        var s=get(i).s;        
        var r=get(i).r;

        gi.n=get(i).n;
        gi.x=parseInt(x);
        gi.y=y ? parseInt(y) : -1;
        gi.s=s ? parseInt(s) : 1;
        gi.r=r ? parseInt(r) : 0;
        gi.t=get(i).t;

        return gi;
    }
}
