import QtQuick 1.1
import "game.js" as G

Menu {
    id: levelMenu

    signal back();
    signal levelSelected(int level, string description, string source);

    margin: 0;
    bgOpacity: 1;

    property bool zoomed: zoom.xScale>1;
    property string level: ""

    onShownChanged: {
        if (!shown) {
            console.debug("LevelMenuShowReset");
            reset();
        }
    }

    function zoomIn()
    {
        zoom.xScale=3;
    }

    function zoomOut()
    {
        zoom.xScale=1;
    }

    function zoomInIn()
    {
        zoom.xScale=20;
    }

    function reset()
    {
        zoomOut();
        stp.isSelected=false;
        tku.isSelected=false;
        mapflick.marker=null;
        levelMenu.level='';
    }

    Flickable {
        id: mapflick
        anchors.fill: parent
        anchors.margins: 0
        contentHeight: bsMap.height
        contentWidth: bsMap.width
        boundsBehavior: Flickable.StopAtBounds
        clip: true;
        interactive: false;
        Image {
            id: bsMap
            fillMode: Image.PreserveAspectFit
            smooth: true
            source: "images/menu/map.svg"
            width: levelMenu.width*1.1
            sourceSize {
                width: levelMenu.width*2;
                //height: 595;
            }
        }

        function mX(r) { return bsMap.width*r; }
        function mY(r) { return bsMap.height*r; }

        // XXX These should use a model and delegates but as we only have two levels..

        LevelStartMarker {
            id: tku;
            x: mapflick.mX(0.4);
            y: mapflick.mY(0.52);
            enabled: !zoomBehaviour.running && levelMenu.visible;
            onSelected: {
                stp.isSelected=false;
                mapflick.marker=tku;
                level='level_demo_1.xml'
            }
            onClicked: {                
                levelSelected(998, 'Level 1', 'level_demo_1.xml');
                //reset();
            }
            source: "images/signs/turku.svg"
        }

        LevelStartMarker {
            id: stp;
            x: mapflick.mX(0.66);
            y: mapflick.mY(0.55);
            enabled: !zoomBehaviour.running && levelMenu.visible;
            onSelected: {
                tku.isSelected=false;
                mapflick.marker=stp;
                level='level_demo_2.xml'
            }
            onClicked: {                
                levelSelected(999, 'Level 2', 'level_demo_2.xml');
                //reset();
            }
            source: "images/signs/stp.svg"            
        }

        property variant marker: null;

        transform: Scale {
            id: zoom
            origin.x: mapflick.marker ? mapflick.marker.x : 0;
            origin.y: mapflick.marker ? mapflick.marker.y : 0;
            xScale: 1.0
            yScale: xScale;

            property alias scale: zoom.xScale

            //Behavior on origin.x { enabled: mapflick.marker ? true : false; NumberAnimation { easing.type: Easing.InOutQuad} }
            //Behavior on origin.y { enabled: mapflick.marker ? true : false; NumberAnimation { easing.type: Easing.InOutQuad} }

            Behavior on xScale {
                enabled: _useScaling
                NumberAnimation {
                    id: zoomBehaviour
                    easing.type: Easing.InOutCubic;
                    duration: 1000;
                }
            }
        }

    }

    Image {
        source: "images/menu/banner.svg"
        x: 0;
        y: parent.height/12;
        height: textBanner.height+8;
        width: textBanner.width+32;
        fillMode: Image.Stretch
        smooth: true
        Text {
            id: textBanner
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 8
            color: "#ffffff"
            font.pixelSize: 32
            text: qsTr("Select level")
        }
    }

    Image {
        fillMode: Image.PreserveAspectFit
        source: "images/menu/banner_back.svg"
        anchors.right: parent.right
        anchors.rightMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 32;
        height: parent.height/8
        smooth: true
        MouseArea {
            anchors.fill: parent
            onClicked: {
                if (zoomed) {
                    zoomOut();
                    tku.isSelected=false;
                    stp.isSelected=false;
                } else {
                    back();
                }
            }
        }
    }

    ScoreDisplay {
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.margins: 16
        opacity: zoomed ? 1.0 : 0.0;
        Behavior on opacity { NumberAnimation { easing.type: Easing.InOutQuad; duration: 200 }  }
        visible: level!==''
        score: _settings.getInt(G.getScoreId(level), 0);
    }

    /*
    XmlListModel {
        id: levelsModel
        source: "levels/levels.xml"
        query: "/bsna/levels/level"

        XmlRole { name: "level"; query: "@id/string()"; isKey: true; }
        XmlRole { name: "description"; query: "@name/string()"; }
        XmlRole { name: "src"; query: "@src/string()"; }
        XmlRole { name: "lat"; query: "@src/string()"; }
        XmlRole { name: "lon"; query: "@src/string()"; }

        onCountChanged: console.debug("Level entries:"+count)

        onStatusChanged: {
            console.debug("Levels status: "+status)
            switch (status) {
            case XmlListModel.Error:
                console.debug("Level loading error:"+errorString())
                break;
            }
        }
    }
    */
}


