/**************************************************************************
 *   Otty the Otter
 *   Copyright (C) 2012-2013 Union of the Baltic Cities Environment and Sustainable Development Secretariat <environment@ubc.net>
 *   Copyright (C) 2012-2013 Kaj-Michael Lang <milang@tal.org>
 *
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 **************************************************************************/

import QtQuick 1.1
import "game.js" as G

Item {
    id: mm
    anchors.fill: parent;

    property alias gameArea: gameAreaLoader.item

    property bool isActive: true;    
    property bool wasMuted: true;    

    onStateChanged: console.debug("*** MMNewState: "+state)

    state: "menu"

    onIsActiveChanged: {
        console.debug("** ISACTIVE: "+isActive)
        if (!isActive) {
            wasMuted=sfx.muted;
            sfx.muted=true;
            if (gameArea) {
                console.debug("Pausing ga!")
                gameArea.state="paused";
            }
        } else {
            sfx.muted=wasMuted;
        }
    }

    states: [
        State { name: "menu"; when: !gameArea; },
        State { name: "prepareloading"; },
        State { name: "loading"; },
        State { name: "ingame"; when: gameArea; }
    ]

    transitions: [
        Transition {
            from: "menu"
            to: "prepareloading"
        },
        Transition {
            from: "prepareloading"
            to: "loading"
            ScriptAction {
                script: { gameAreaLoader.loadLevel(); }
            }
        },
        Transition {
            from: "loading"
            to: "ingame"
        }
    ]

    Splash {
        id: bgSplash
        visible: mm.state=="menu" || mm.state=="loading";
        onSplashCompleted: {
            mainMenu.show();
            // sfx.playMusic();
        }
        onSplashHideCompleted: {

        }

        onVisibleChanged: {
            if (!visible)
                sfx.stopMusic();
        }
    }

    Item {
        id: bgBox
        anchors.fill: parent;
        anchors.margins: mainMenu.width/2
        opacity: 0.9;
        visible: bgSplash.visible
        Rectangle {
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.bottom: parent.bottom
            width: 1;
        }
        Rectangle {
            anchors.top: parent.top
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            width: 1;
        }
        Rectangle {
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: 1
        }
    }

    Menu {
        id: mainMenu
        width: parent.width/11
        x: 4
        margin: 16;
        height: buttons.height;
        useBg: false;

        onShownChanged: {
            if (!shown) {
                bgSplash.startHide();
            }
        }

        Column {
            id: buttons
            anchors.centerIn: parent;
            width: parent.width;
            spacing: 8
            Button {
                source: "images/buttons/play.svg";
                onClicked: {
                    sfx.playSound(1);
                    mainMenu.hide();
                    levelMenu.show();
                }
            }
            Button {
                source: "images/buttons/help.svg";
                onClicked: {
                    sfx.playSound(1);
                    mainMenu.hide();
                    helpMenu.show();
                }
            }
            Button {
                source: "images/buttons/info.svg";
                onClicked: {
                    sfx.playSound(1);
                    mainMenu.hide();
                    aboutMenu.show();
                }
            }
            CheckButton {
                id: isSound
                sourceOff: "images/buttons/sound_off.svg"
                sourceOn: "images/buttons/sound_on.svg"
                checked: !sfx.muted;
                onClicked: {
                    sfx.muted=!checked;
                    if (sfx.muted)
                        sfx.stopMusic();
                    else
                        sfx.playMusic();
                }
            }
            Button {
                source: "images/buttons/end.svg";
                visible: _needsQuit;
                onClicked: {
                    sfx.stopMusic();
                    sfx.stop();
                    Qt.quit();
                }
            }
        }
    }        

    AboutMenu {
        id: helpMenu
        margin: bgBox.anchors.margins
        title: "Otty the Otter - Help"
        body: "The aim of the game is to travel from Turku to St Petersburg and back, using as little as possible of water."+
              " Otty the Otter has 3000 liters of water for use. Otty can trade his water for food in order to keep up his energy."+
              " He saves his water supply by trying to eat food with a small water footprint.<br/>"+              
              "<h3>Stearing Otty</h3>"+
              " Otty can go forward, backward and jump. When he is in the air he can lean forward and backwards."+
              " You can stear Otty with the on-screen cursor keys, or in case your device has a keyboard, using the cursor keys."+
              "<h3>Food items</h3>"+
              "Production of each food item requires a different amount of water, the water footprints are different."+
              "<center><table width='90%'><tr><th width='120'>Food<th><th>Water footprint</th></tr>"+
              "<tr><td><img src='images/food/apple.svg' width='96'/></td><td align='right'>70 liters (100gram)</td></tr>"+
              "<tr><td><img src='images/food/banana.svg' width='96'/></td><td align='right'>160 liters (200gram)</td></tr>"+
              "<tr><td><img src='images/food/orangejuice.svg' width='64'/></td><td align='right'>200 liters (2 dl)</td></tr>"+
              "<tr><td><img src='images/food/choco.svg' width='96'/></td><td align='right'>1700 liters (100gram)</td></tr>"+
              "<tr><td><img src='images/food/hamburger.svg' width='96'/></td><td align='right'>2400 liters (150gram)</td></tr>"+
              "</table></center>"

        body_ru: "Цель игры – добраться из Турку в Санкт-Петербург используя как можно меньше воды. В нашей игре выдра Отти имеет всего 300 литров воды в запасе и может  менять свою воду на продукты, чтобы пополнить запасы энергии. Она старается сэкономить воду, выбирая продукты, создающие наименьший водный след. Производство различных продуктов требует разного объема воды, и, соответственно, создает разный водный след.<br/>"+
                 "<tr><td><img src='images/food/apple.svg' width='96'/></td><td align='right'>70 литров (100г)</td></tr>"+
                 "<tr><td><img src='images/food/banana.svg' width='96'/></td><td align='right'>160 литров (200г)</td></tr>"+
                 "<tr><td><img src='images/food/orangejuice.svg' width='64'/></td><td align='right'>200 литров (2 дл)</td></tr>"+
                 "<tr><td><img src='images/food/choco.svg' width='96'/></td><td align='right'>1700 литров (100г)</td></tr>"+
                 "<tr><td><img src='images/food/hamburger.svg' width='96'/></td><td align='right'>2400 литров (150г)</td></tr>"+
                 "</table></center>"

        body_fi: "Pelin tavoitteena on matkata Turusta Pietariin käyttäen mahdollisimman vähän vettä. Pelissä Ottylla on käytössä rajallinen määrä vettä, 3000 litraa. Otty voi vaihtaa vesivarastoaan ruoka-aineisiin pitääkseen yllä energiatasoaan. Hän voi säästää vettä yrittäen syödä ruoka-aineita joilla on pieni vesijalanjälki. Kunkin ruoka-aineen valmistamiseen on kulunut eri määrä vettä, tuotteiden vesijalanjäljet ovat seuraavat: "+
                 "<center><table width='90%'><tr><th width='120'>Ruoka<th><th>Vesijalanjälki</th></tr>"+
                 "<tr><td><img src='images/food/apple.svg' width='96'/></td><td align='right'>70 litraa (100g)</td></tr>"+
                 "<tr><td><img src='images/food/banana.svg' width='96'/></td><td align='right'>160 litraa (200g)</td></tr>"+
                 "<tr><td><img src='images/food/orangejuice.svg' width='64'/></td><td align='right'>200 litraa (2 dl)</td></tr>"+
                 "<tr><td><img src='images/food/choco.svg' width='96'/></td><td align='right'>1700 litraa (100g)</td></tr>"+
                 "<tr><td><img src='images/food/hamburger.svg' width='96'/></td><td align='right'>2400 litraa (150g)</td></tr>"+
                 "</table></center>"
        onBack: {
            sfx.playSound(2);
            bgSplash.startShow();
        }
    }

    AboutMenu {
        id: aboutMenu
        margin: bgBox.anchors.margins
        title: "Otty the Otter - About"
        body: "Otty the Otter game was developed in the project “<a href='http://www.ubc-environment.net/index.php/main:bsna'>Baltic Sea needs Actions 2012–2013</a>”"+
              ", co-financed by the <a href='http://www.ymparisto.fi/'>Ministry of Environment of Finland</a>."+
              "The game is developed by the <a href='http://www.ubc-environment.net/?utm_source=otty&utm_medium=about&utm_campaign=otty'>Union of the Baltic Cities, Commission on Environment Secretariat.</a><br/><br/>"+
              "Copyright 2012-2013 Union of the Baltic Cities, Commission on Environment Secretariat.<br/><center>"+
              "<p><img src='images/logos/ubc.png'/></p>"+
              "<p><img src='images/logos/stp.png'/></p>"+
              "<p><img src='images/logos/ym.png'/></p>"+
              "</center><center>"+
              "<h3>Development team</h3>"+
              "<h4>Producer and Creative Director:</h4>Stella Aaltonen"+
              "<h4>Lead Designer and artist:</h4>Sari Sariola"+
              "<h4>Additional Art:</h4>Moira Åkerman"+
              "<h4>Programmer:</h4>Kaj-Michael Lang"+
              "</center>"+
              "<h3>License</h3>"+
              "<small>The source code is licensed under the GPLv3 license.<br/>"+
              "Graphics and artwork are licensed under the Createive Commons Attribution-NonCommercial-NoDerivs 3.0 Unported (CC BY-NC-ND 3.0) license.<br/><br/>"+license+"</small>";

        // XXX "<h3>Music</h3><a href='http://incompetech.com/'>Pixel Peeker Polka - faster by Kevin MacLeod</a>, CC BY 3.0"

        property string license: 'Otty the Otter is free software: you can redistribute it and/or modify ' +
                                 'it under the terms of the GNU General Public License as published by ' +
                                 'the Free Software Foundation, either version 3 of the License, or ' +
                                 '(at your option) any later version.<br /><br />' +

                                 'Otty the Otter is distributed in the hope that it will be useful, ' +
                                 'but WITHOUT ANY WARRANTY; without even the implied warranty of ' +
                                 'MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the ' +
                                 'GNU General Public License for more details.<br /><br />' +

                                 'You should have received a copy of the GNU General Public License ' +
                                 'along with this program. If not, see <a href="http://www.gnu.org/licenses">http://www.gnu.org/licenses</a><br />'

        onBack: {
            sfx.playSound(2);
            bgSplash.startShow();
        }
    }

    LevelMenu {
        id: levelMenu;

        onBack: {
            sfx.playSound(2);
            bgSplash.startShow();
            levelMenu.hide();
        }
        onLevelSelected: {
            sfx.playSound(1);
            levelMenu.hide();            
            mm.state="prepareloading"
            prepareGame(source, description);
            // Trigger loading
            levelLoadTrigger.start();            
        }
    }

    Timer {
        id: levelLoadTrigger
        interval: 400
        repeat: false;
        onTriggered: {
            mm.state="loading"            
        }
    }

    GameMessage {
        id: gameLoading
        text: qsTr("Loading level");
        visible: mm.state=="loading" || mm.state=="prepareloading"
        Text {
            visible: gameAreaLoader.status==Loader.Loading;
            anchors.horizontalCenter: parent.horizontalCenter;
            anchors.bottom: parent.bottom;
            text: Math.round(gameAreaLoader.progress*100);
        }
    }

    GameMessage {
        id: gameError
        text: ""
        visible: text!=''
    }

    Loader {
        id: gameAreaLoader
        anchors.fill: parent;
        focus: true;
        sourceComponent: null
        onLoaded: {
            console.debug("Loaded");
            if (gameArea) {
                gameArea.gameError.connect(gameError);
                gameArea.gameEnded.connect(gameEnd);
                gameArea.gameLoaded.connect(gameLoaded);                
            }
            sfx.stopMusic();
        }
        onProgressChanged: {
            console.debug("GameAreaLoad: "+progress)
        }
        onStatusChanged: {
            console.debug("GALStatus: "+status)            
            if (status==Loader.Error) {
                gameError();
            }
        }

        function clear()
        {
            sourceComponent=undefined;
        }

        function loadLevel()
        {
            gameAreaLoader.sourceComponent=gameAreaComponent;
        }

        function prepareLevel(level, description, hs)
        {
            clear();
            currentLevel=level;
            currentLevelDesc=description;            
        }

        function reLoad() {
            clear();
            gameAreaLoader.sourceComponent=gameAreaComponent;
        }

        property string currentLevel: ""
        property string currentLevelDesc: ""
        property int currentLevelHighScore: 0;

        Component {
            id: gameAreaComponent
            GameArea {
                level: currentLevel;
                levelDescription: currentLevelDesc;
                levelHighScore: currentLevelHighScore;
            }
        }
    }

    function prepareGame(source, desc) {
        gameAreaLoader.prepareLevel(source, desc);
    }

    function gameLoaded()
    {
        mm.state='ingame'
    }

    function gameError()
    {
        console.debug("*Internal error!*")
        gameError.text="An error occured"
        gameEnd();
    }

    function gameEnd()
    {
        gameAreaLoader.clear();
        gameLoading.visible=false;
        bgSplash.startShow();
    }

    function gameRestartLevel()
    {
        gameAreaLoader.reLoad()
    }

    function getCurrentLevel()
    {
        return false;
    }

    function getNextLevel()
    {
        return false;
    }

}
