import QtQuick 1.1

Item {
    id: menuBox

    property bool useBg: true;
    property bool shown: state==='shown';

    visible: y>=-menuBox.height

    property alias bgOpacity: bg.opacity    

    Rectangle {
        id: bg
        anchors.fill: parent;
        opacity: _useOpacity ? 0.6 : 1.0;
        color: "#ffffff"
        visible: useBg
    }
    y: -menuBox.height
    x: (parent.width-width)/2
    width: parent.width-2*margin
    height: parent.height-2*margin;

    property real margin: 32;

    property real showOpacity: _useOpacity ? 0.9 : 1.0
    property real hideOpacity: _useOpacity ? 0.0 : 1.0

    signal shown();
    signal hidden();

    state: "hidden"

    states: [
        State { name: "hidden"; },
        State { name: "shown"; }
    ]

    function show() { state='shown' }
    function hide() { state='hidden' }

    transitions: [
        Transition {
            from: "shown"
            to: "hidden"
            ParallelAnimation {
                NumberAnimation { target: menuBox; property: "y"; easing.type: Easing.InBack; to: -menuBox.height; duration: 500 }
                NumberAnimation { target: menuBox; property: "opacity"; to: hideOpacity; duration: 500 }                
                onCompleted: hidden();
            }
        },
        Transition {
            from: "hidden"
            to: "shown"
            ParallelAnimation {
                NumberAnimation { target: menuBox; property: "y"; easing.type: Easing.InBack; to: margin; duration: 500 }
                NumberAnimation { target: menuBox; property: "opacity"; to: showOpacity; duration: 400 }
                onCompleted: shown();
            }
        }
    ]
}
