import QtQuick 1.1

Item {
    id: sdc
    width: scoreDisplay.width
    height: scoreDisplay.height

    property int score: 0;
    property int finalScore: 0;
    property int highScore: 0;
    property alias maxlength: scoreDisplay.scoreLen

    property bool background: false;

    property int cx: x+width/2;
    property int cy: y+height/2;

    signal scoreCompleted();

    Behavior on score { NumberAnimation { easing.type: Easing.OutExpo; duration: 400 } }

    property bool isFixed: false;

    function start()
    {
        scoreAnimation.start();
    }

    function addScore(ns)
    {
        sdc.score+=ns;
    }

    NumberAnimation {
        id: scoreAnimation;
        target: scoreDisplay;
        property: "s";
        duration: 1500
        easing.type: Easing.InQuad
        from: 0;
        to: sdc.finalScore;
        onCompleted: {
            scoreCompleted();
            sdc.score=sdc.finalScore;
            isFixed=false;
        }
    }

    Rectangle {
        id: bg
        visible: sdc.background;
        anchors.fill: parent;
    }

    Text {
        id: scoreDisplay
        font.pixelSize: 28
        color: "black"
        text: isFixed ? formatScore(s) : formatScore(score);        
        styleColor: "#347add"
        style: Text.Outline
        smooth: false;

        property int scoreLen: 8
        property int s: 0

        function formatScore(s) {
            var n;
            var digs;
            var fs="";

            if (s===0)
                return "0000000000";
            n=Math.floor(log10(s))+1;
            digs=scoreLen-n;            
            for (var i=0;i<digs;i++) {
                fs=fs.concat("0");
            }

            fs+=s.toString();
            return fs;
        }

        function log10(val) {
            return Math.log(val)/Math.LN10;
        }
    }
}
