import QtQuick 1.1
import "game.js" as G

Item
{
    id: scoreItem

    signal clearScore()
    property int scoresCnt: 0
    property int fntSize: parent.height/30

    ListModel {
        id: scoresModel;
    }

    Item {
        id: noScores;
        scale: 0.1;
        width: parent.width;
        visible: scoresCnt===0 ? true : false;
        anchors.centerIn: parent;
        anchors.horizontalCenter: parent.horizontalCenter
        Behavior on scale { NumberAnimation { easing.amplitude: 1.1; duration: 1000; easing.type: Easing.InOutBounce} }

        Text {
            width: parent.width;
            anchors.centerIn: parent;
            color: "#ffffff"
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: 82
            horizontalAlignment: Text.AlignHCenter
            text: "No\nscores\nyet"
        }

    }

    Component {
        id: scoreDelegate
        Rectangle {
            height: sr.height;
            width: parent.width;
            color: getLevelColor(level);
            radius: 8;

            Row {
                id: sr
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 8;
                anchors.rightMargin: 8;
                height: fntSize*2.6;
                spacing: 0;
                Column {
                    id: sc
                    width: parent.width/2.9;
                    Text { text: score; font.pixelSize: fntSize; color: "white"; width: parent.width;}
                    Text { text: 'Taps:'+clicks; font.pixelSize: fntSize-4;color: "white"; width: parent.width; }
                }
                Column {
                    width: parent.width-sc.width;
                    Text { text: getTS(time); horizontalAlignment: Text.AlignRight; font.pixelSize: fntSize-2; color: "white"; width: parent.width;}
                    Text { text: getLevelStr(level); horizontalAlignment: Text.AlignRight; font.pixelSize: fntSize; color: "white"; width: parent.width;}
                }
            }
        }
    }

    Rectangle {
        height: 68;
        color: "#a60909"
        width: parent.width
        id: l
        Text {
            text: "Highscores"
            color: "#ffed5e"
            font.pixelSize: 52
            height: 64;
            anchors.centerIn: parent;
        }
    }

    ListView {
        clip: true;
        id: scores
        anchors.topMargin: 8;
        anchors.fill: parent;
        model: scoresModel
        delegate: scoreDelegate
        spacing: 4;
    }

    function prepareView() {
        updateScores();        
        noScores.scale=1.0;
    }

    function hideView()
    {
        noScores.scale=0.1;
    }

    function updateScores()
    {
        scoresModel.clear();
        var sdata=G.scoresLoad();
        var i;
        for (i = 0; i < sdata.length; i ++) {
            console.debug('Adding to model:'+sdata[i].score);
            scoresModel.append(sdata[i])
        }
        scoresCnt=sdata.length;
        console.debug('Loaded:'+i);
    }

    function getTS(t) {
        var td=new Date();
        td.setTime(t);
        return td.toDateString();
    }

    function getLevelColor(le)
    {
        switch (le) {
        case 1:
            return '#008b00';
        case 2:
            return '#8b8b00';
        case 3:
            return '#8b0000';
        }
        return '-';
    }
    function getLevelStr(le)
    {
        switch (le) {
        case 1:
            return 'E';
        case 2:
            return 'N';
        case 3:
            return 'H';
        }
        return '-';
    }

}
