import QtQuick 1.1

Item {
    id: s
    anchors.fill: parent;

    property bool animateClouds: visible
    property bool visibleLogo: true;
    property bool visibleOtty: true;

    property int showInterval: 500
    property int hideInterval: 250

    Component.onCompleted: {
        st.start();
    }

    function startShow()
    {
        st.cnt=0;
        st.start();
    }

    function startHide()
    {
        sth.cnt=0;
        sth.start();
    }

    signal splashCompleted();
    signal splashHideCompleted();

    // Timer for showing items.
    Timer {
        id: st
        interval: showInterval;
        repeat: true;
        property int cnt: 0

        onTriggered: {
            switch (cnt) {
            case 0:
                logo.state="shown";
                break;
            case 1:
                otter.state="shown";
                break;
            case 2:
                splashCompleted();
                break;
            case 3:
                stop();
            }
            cnt++;
        }
    }

    // Timer for hiding animation
    Timer {
        id: sth
        interval: hideInterval;
        repeat: true;
        property int cnt: 0

        onTriggered: {
            switch (cnt) {
            case 0:
                logo.state="hidden";
                break;
            case 1:
                otter.state="hidden";
                break;
            case 2:
                splashHideCompleted();
                break;
            case 3:
                stop();
            }
            cnt++;
        }
    }

    signal clicked();

    Image {
        anchors.fill: parent
        id: splashImage
        fillMode: Image.PreserveAspectCrop
        source: "images/menu/bg2.svg"
        smooth: true;

        Item {
            id: clouds;
            anchors.fill: parent;

            property bool animate: false;
            visible: animate;

            Cloud { animate: parent.animate; y: parent.height/4; x: -width; toX: parent.width/0.6; velocity: 13; }
            Cloud { animate: parent.animate; y: parent.height/3.5; x: width; toX: parent.width; velocity: 11; size: 0.9; }
            Cloud { animate: parent.animate; y: parent.height/5; x: parent.width/2; toX: parent.width; velocity: 12; }
            Cloud { animate: parent.animate; y: parent.height/6; x: parent.width/3; toX: parent.width; velocity: 11; size: 0.9 }
            Cloud { animate: parent.animate; y: parent.height/7; x: parent.width/0.9; toX: parent.width; velocity: 10; }
        }

        Image {
            id: logo
            x: parent.width/2-width;
            y: x
            source: _isDemo ? "images/otty/logo_demo.svg" : "images/otty/logo.svg"
            width: parent.width/3
            fillMode: Image.PreserveAspectFit
            // smooth: !logoAnim.running;
            state: "hidden"
            visible: visibleLogo

            property int marginRatio: 13

            states: [
                State {
                    name: "hidden";
                    PropertyChanges { target: logo; y: -logo.height-marginRatio; }
                },
                State {
                    name: "shown";
                    PropertyChanges { target: logo; y: parent.height/marginRatio; }
                }
            ]

            transitions: [
                Transition {
                    from: "hidden"
                    to: "shown"
                    NumberAnimation {
                        id: logoAnim
                        easing.amplitude: 1.1
                        easing.type: Easing.OutElastic
                        properties: "y";
                        duration: 1400
                    }
                },Transition {
                    from: "shown"
                    to: "hidden"
                    NumberAnimation {
                        easing.period: 0.6
                        easing.amplitude: 0.65
                        easing.type: Easing.OutElastic
                        properties: "y";
                        duration: 1000
                    }
                }
            ]
        }

        Image {
            id: otter
            x: -otter.width
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 8
            source: "images/otty/otty_bike_front.svg"
            height: parent.height/1.4
            fillMode: Image.PreserveAspectFit
            smooth: !ottyAnim.running
            state: "hidden"
            visible: visibleOtty

            states: [
                State { name: "hidden";
                    PropertyChanges { target: otter; x: -otter.width; }
                },
                State { name: "shown";
                    PropertyChanges { target: otter; x: parent.width/2; }
                }
            ]

            transitions: [
                Transition {
                    from: "hidden"
                    to: "shown"
                    NumberAnimation {
                        id: ottyAnim
                        easing.period: 0.35
                        easing.amplitude: 1
                        easing.type: Easing.OutElastic
                        properties: "x";
                        duration: 1300
                    }
                }, Transition {
                    from: "shown"
                    to: "hidden"
                    NumberAnimation {
                        id: ottyAnim2
                        easing.period: 0.6
                        easing.amplitude: 0.65
                        easing.type: Easing.OutElastic
                        properties: "x";
                        duration: 1000
                    }
                }
            ]
        }
    }

    MouseArea {
        anchors.fill: parent;
        enabled: !st.running
        onClicked: s.clicked();
    }
}
