/*
  A scooter wheel
  The wheel will track if it is in contact with a ground element (gid is 500 or 300)
  and will signal it with a propery change (isOnGround)
  */
import QtQuick 1.1
import Box2D 1.0

Body {
	id: w
    property real size: 52;
    fixedRotation: false;
    sleepingAllowed: true;
	height: size;
	width: size;

	property alias fx: wi.x
	property alias fy: wi.y

    property alias density: c.density
    property alias friction: c.friction    

    property real cx: wi.x+wi.width/2
    property real cy: wi.y+wi.height/2

    property int gcnt: 0
    property int group: 0
    property bool isOnGround: gcnt>0;

    property int groundItem: 0;

    signal beginContact(variant other);
    signal endContact(variant other);

	fixtures: Circle {
		id: c
		radius: size/2
        density: 0.8;
        friction: 2.0;
        restitution: 0.008;
        groupIndex: w.group
		onBeginContact: {
            var p=other.parent;
            if (p.gid===500 || p.gid===300) {
                gcnt++;
            }
            if (p && p.gid)
                groundItem=p.gid;            
            w.beginContact(other.parent);
		}
		onEndContact: {
            var p=other.parent;
            if (p.gid===500 || p.gid===300) {
                gcnt--;
            }
            groundItem=0;
            w.endContact(other);
		}
	}

	Image {		
		id: wi
		anchors.centerIn: c
        source: "images/bike/wheel.svg"
        smooth: false;
		width: w.width;
		height: w.height;
        sourceSize {
            width: _isFast ? 128 : 64;
            height: width;
        }
	}
}
