.pragma library

var VERSION="1.0.0"

var FONT_LSMALL=22;
var FONT_DEFAULT=24;
var FONT_SLARGE=26;
var FONT_XLARGE=32;

var DEFAULT_MARGIN=16
var HEADER_DEFAULT_HEIGHT_PORTRAIT = 72;
var HEADER_DEFAULT_HEIGHT_LANDSCAPE = 46;

// s=Score, l=Level, ts=Timestamp
var _DB_SCORES="CREATE TABLE IF NOT EXISTS hs (s int not null, c int not null, l int not null, ts int not null, user char)"

var gameLevel=1;
var gameButtons=3;
var gameData;
var blinkTime;
var clickTime;
var highscore=0;
var score=0;
var highscores;
var rndprev=-1;
var db;

function mapValue(x, in_min, in_max, out_min, out_max)
{
    if (x>in_max)
        x=in_max;
    else if (x<in_min)
        x=in_min;
    return (x - in_min) * (out_max - out_min) / (in_max - in_min) + out_min;
}

function getTotalForce(x, y)
{
    return Math.sqrt(x*x+y*y);
}

function getScoreId(level) {
    return level+'_HighScore';
}

function getdb()
{
    return openDatabaseSync("bsnagamedb", "1.0", "GameDatabase", 6500);
}

function init()
{
    highscores=new Array();
    try {
        db=getdb();
        db.transaction(function(tx) { tx.executeSql(_DB_SCORES); });
    } catch (e) {
        console.debug(e);
        return false;
    }
    return true;
}

function scoreAdd(l,s,c)
{
    if (s<1)
        return;
    scoreSave({'score': s, 'level': l, 'clicks': c });
}

function scoresGet()
{
    return highscores;
}

function scoresLoad()
{
    highscores=new Array();

    try {
    db.readTransaction(
                function(tx) {
                    var rs=tx.executeSql('SELECT s,c,l,ts FROM hs ORDER BY s DESC LIMIT 10');
                    if (rs.rows.length > 0) {
                        for (var i=0; i<rs.rows.length; i++) {
                            var s=rs.rows.item(i)
                            highscores.push({'score': parseInt(s.s, 10), 'clicks': parseInt(s.c,10), 'level': parseInt(s.l,10), 'time': parseInt(s.ts, 10)})
                            console.debug('LScore: '+s.s)
                        }
                    }
                });
    } catch (e) {
        console.debug('Load: '+e);
    }
    return highscores;
}

function scoreSave(s)
{
    try {
        db.transaction(
                    function(tx) {
                        var ts=new Date();
                        tx.executeSql("INSERT INTO hs (s,c,l,ts) VALUES (?,?,?,?)", [s.score,s.clicks,s.level,ts.getTime()]);
                    })
    } catch (e) {
        console.debug('Save:'+e)
    }
}

function scoresSave()
{
    db.transaction(
                function(tx) {
                    tx.executeSql("DELETE FROM hs");
                    for (var i=0;i<highscores.length;i++) {
                        tx.executeSql("INSERT INTO hs (s,c,l,ts) VALUES (?,?,?,?)", [highscores.score,highscores.clicks,highscores.level,highscores.time]);
                    }
                })
}

function scoresClear()
{
    db.transaction(function(tx) { tx.executeSql("DELETE FROM hs"); })
}

function scoresSort()
{
    highscores.sort(function(a,b){return b.s - a.s});
}

// Get random number 1-rmax, but never give the same value twice in a row
function getRandom(rmax)
{
    var r;

    do {
        r=Math.floor(Math.random()*rmax)+1;
    } while (rndprev===r)

        rndprev=r;
    return r;
}
