import QtQuick 1.1
import QtMultimediaKit 1.1

Item {
    id: gameSounds
    property bool muted: false
    property real volume: 0.8;
    property real sfxVolume: 0.8;
    property real musicVolume: 0.8;
    property string prefix: "file:///opt/bsna/"

    function stop()
    {
        gameSounds.muted=true;
        mymixer.stopPlayback();
    }

    SoundEffect {
        id: gameOverHighScoreSound
        //source: prefix+"sounds/sharp_echo.wav"
        muted: gameSounds.muted
    }
    SoundEffect {
        id: gameOverFailSound
        //source: prefix+"sounds/sharp_echo.wav"
        muted: gameSounds.muted
    }
    SoundEffect {
        id: btn1
        source: prefix+"sounds/menu.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: btn2
        source: prefix+"sounds/back.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: jump1
        source: prefix+"sounds/jump1.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: jump2
        source: prefix+"sounds/jump2.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: pickup1
        source: prefix+"sounds/pickup1.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: pickup2
        source: prefix+"sounds/pickup2.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: hit1
        source: prefix+"sounds/hit1.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: hit2
        source: prefix+"sounds/hit2.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: whit1
        source: prefix+"sounds/wheelhit1.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: whit2
        source: prefix+"sounds/wheelhit2.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    SoundEffect {
        id: hhard
        source: prefix+"sounds/hithard.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }

    SoundEffect {
        id: hhead
        source: prefix+"sounds/hithead.wav"
        volume: sfxVolume
        muted: gameSounds.muted
    }
    Audio {
        id: bgMusic
        volume: musicVolume
        autoLoad: false;
        muted: gameSounds.muted
        // source: "file:///opt/bsna/music/kevin_macleod___pixel_peeker_polka.ogg"
        Behavior on volume {
            enabled: bgMusic.fadeEnabled;
            NumberAnimation { easing.type: Easing.OutQuad; duration: 2500 }
        }
        property bool fadeEnabled: true;
    }


    function playMusic()
    {
        if (!bgMusic.playing) {
            bgMusic.fadeEnabled=false;
            bgMusic.volume=0;
            bgMusic.play();
            bgMusic.fadeEnabled=true;
            fadeInMusic();
        }
    }

    function fadeOutMusic()
    {
        if (bgMusic.playing)
            bgMusic.volume=0;
    }

    function fadeInMusic()
    {
        if (bgMusic.playing)
            bgMusic.volume=musicVolume;
    }

    function stopMusic()
    {
        bgMusic.stop();
        bgMusic.fadeEnabled=false;
    }

    // For playing of effects with adjustment to volume, only for sounds that we like to adjust volume for
    function playSfx(sid, vol) {
        if (muted)
            return;
        switch (sid) {
        case 81:
            hit1.volume=vol;
            hit1.play();
            break;
        case 82:
            hit2.volume=vol;
            hit2.play();
            break;
        case 83:
            whit1.volume=vol;
            whit1.play();
            break;
        case 84:
            whit2.volume=vol;
            whit2.play();
            break;
        case 90:
            hhard.volume=vol;
            hhard.play();
            break;
        case 91:
            hhead.volume=vol;
            hhead.play();
            break;
        }
    }

    // Quick sound playing, not extras
    function playSound(sid) {
        if (muted)
            return;
        switch (sid) {
        case 1:
            btn1.play();
            break;
        case 2:
            btn2.play();
            break;
        case 10:
            gameOverHighScoreSound.play();
            break;
        case 20:
            gameOverFailSound.play();
            break;
        case 62:
            pickup1.play();
            break;
        case 63:
            pickup2.play();
            break;
        case 71:
            jump1.play();
            break;
        case 72:
            jump2.play();
            break;
        case 81:
            hit1.play();
            break;
        case 82:
            hit2.play();
            break;
        case 83:
            whit1.play();
            break;
        case 84:
            whit2.play();
            break;
        case 90:
            hhard.play();
            break;
        }
    }
}
